@@ -18,6 +18,7 @@ package org.uberfire.ext.wires.client.demo.grids;
 import java.util.ArrayList;
 import java.util.List;
 import java.util.Set;
+import java.util.function.Consumer;
 
 import javax.annotation.PostConstruct;
 import javax.enterprise.context.Dependent;
@@ -119,8 +120,8 @@ public class WiresGridsDemoPresenter implements WiresGridsDemoView.Presenter {
     }
 
     @WorkbenchMenu
-    public Menus getMenus() {
-        return menus;
+    public void getMenus(final Consumer<Menus> menusConsumer) {
+        menusConsumer.accept(menus);
     }
 
     @PostConstruct
@@ -214,7 +215,6 @@ public class WiresGridsDemoPresenter implements WiresGridsDemoView.Presenter {
 
     private GridWidget makeGridWidget1() {
         final GridData grid1 = new BaseGridData(false);
-        grid1.setHeaderRowCount(2);
         final GridWidget gridWidget1 = new BaseGridWidget(grid1,
                                                           this,
                                                           view.getGridLayer(),
