@@ -21,6 +21,8 @@ import java.util.Set;
 import java.util.function.Supplier;
 
 import org.eclipse.jgit.transport.CredentialsProvider;
+import org.eclipse.jgit.transport.ReceiveCommand;
+import org.eclipse.jgit.transport.UploadPack;
 import org.uberfire.java.nio.IOException;
 import org.uberfire.java.nio.base.FileSystemState;
 import org.uberfire.java.nio.base.options.CommentedOption;
@@ -35,6 +37,7 @@ import org.uberfire.java.nio.file.attribute.UserPrincipalLookupService;
 import org.uberfire.java.nio.file.spi.FileSystemProvider;
 import org.uberfire.java.nio.fs.jgit.util.Git;
 import org.uberfire.java.nio.fs.jgit.util.model.CommitInfo;
+import org.uberfire.java.nio.security.FileSystemUser;
 
 public class JGitFileSystemProxy implements JGitFileSystem {
 
@@ -176,6 +179,30 @@ public class JGitFileSystemProxy implements JGitFileSystem {
         return cachedSupplier.get().hasBeenInUse();
     }
 
+    @Override
+    public void notifyExternalUpdate() {
+        cachedSupplier.get().notifyExternalUpdate();
+    }
+
+    @Override
+    public void notifyPostCommit(int exitCode) {
+        cachedSupplier.get().notifyPostCommit(exitCode);
+    }
+
+    @Override
+    public void checkBranchAccess(final ReceiveCommand command,
+                                  final FileSystemUser user) {
+        cachedSupplier.get().checkBranchAccess(command,
+                                               user);
+    }
+
+    @Override
+    public void filterBranchAccess(final UploadPack uploadPack,
+                                   final FileSystemUser user) {
+        cachedSupplier.get().filterBranchAccess(uploadPack,
+                                                user);
+    }
+
     @Override
     public FileSystemProvider provider() {
         return cachedSupplier.get().provider();
